@@ -5,7 +5,7 @@
 #  File author(s): Thomas Cokelaer <cokelaer@gmail.com>
 #
 """Common tools to get the correct filename and pathname. """
-__version__ = "$Rev: 52 $"
+__version__ = "$Rev: 60 $"
 import pkg_resources
 try:
     version = pkg_resources.require("easydev")[0].version
@@ -28,6 +28,9 @@ from decorators import *
 import doc
 from doc import *
 
+import easytest
+from easytest import *
+
 import logging_tools
 from logging_tools import *
 
